@@ -1,8 +1,8 @@
-## summary.phylo.R (2021-11-27)
+## summary.phylo.R (2022-03-01)
 
 ##   Print Summary of a Phylogeny, "multiPhylo" operators, node degrees
 
-## Copyright 2003-2021 Emmanuel Paradis, 2006 Ben Bolker, and Klaus Schliep 2016
+## Copyright 2003-2022 Emmanuel Paradis, 2006 Ben Bolker, and Klaus Schliep 2016
 
 ## This file is part of the R-package `ape'.
 ## See the file ../COPYING for licensing issues.
@@ -218,11 +218,10 @@ c.multiPhylo <- function(..., recursive = TRUE)
     x
 }
 
-`[<-.multiPhylo` <- function(x, ..., value)
+`[<-.multiPhylo` <- function(x, i, value)
 {
-###    ## recycling is allowed so no need to check: length(value) != length(..1)
-###    dots <- list(...)
-###    dots <- if (length(dots)) dots[[1]] else seq_along(x) # see issue #36 on GH
+    ## recycling is allowed so no need to check length(value) != length(i)
+    if (missing(i)) i <- seq_along(x)
 
     ## check that all elements in 'value' inherit class "phylo"
     test <- unlist(lapply(value, function(xx) !inherits(xx, "phylo")))
@@ -232,27 +231,41 @@ c.multiPhylo <- function(..., recursive = TRUE)
     oc <- oldClass(x)
     class(x) <- NULL
 
-    if (is.null(attr(x, "TipLabel"))) {
-        x[..1] <- value
-###        x[dots] <- value
+    TipLabel.x <- attr(x, "TipLabel")
+    TipLabel.value <- attr(value, "TipLabel")
+
+    if (is.null(TipLabel.x)) {
+        if (!is.null(TipLabel.value))           # to solve PR #45
+            value <- .uncompressTipLabel(value) #
+        x[i] <- value
         class(x) <- oc
         return(x)
     }
 
-    x[..1] <- 0L # in case x needs to be elongated
-###    x[dots] <- 0L # in case x needs to be elongated
+    ## to solve PR #45
+    if (is.null(TipLabel.value)) {
+        x <- .uncompressTipLabel(x)
+        class(x) <- NULL
+    } else {
+        if (!identical(TipLabel.x, TipLabel.value)) {
+            x <- .uncompressTipLabel(x)
+            class(x) <- NULL
+            value <- .uncompressTipLabel(value)
+        }
+    }
+
+    x[i] <- 0L # in case x needs to be elongated
     class(x) <- oc
     j <- 1L
-    for (i in ..1) {
-###    for (i in dots) {
+    for (k in i) {
         ## x is of class "multiPhylo", so this uses the operator below:
-        x[[i]] <- value[[j]]
+        x[[k]] <- value[[j]]
         j <- j + 1L
     }
     x
 }
 
-`[[<-.multiPhylo` <- function(x, ..., value)
+`[[<-.multiPhylo` <- function(x, i, value)
 {
     if (!inherits(value, "phylo"))
         stop('trying to assign an object not of class "phylo" into an object of class "multiPhylo".')
@@ -275,14 +288,14 @@ c.multiPhylo <- function(..., recursive = TRUE)
         value$edge[ie, 2] <- 1:n
     }
 
-    x[[..1]] <- value
+    x[[i]] <- value
     class(x) <- oc
     x
 }
 
-`$<-.multiPhylo` <- function(x, ..., value)
+`$<-.multiPhylo` <- function(x, i, value)
 {
-    x[[..1]] <- value
+    x[[i]] <- value
     x
 }
 
@@ -294,7 +307,7 @@ degree.phylo <- function(x, details = FALSE, ...)
     res <- tabulate(x$edge, N)
     if (details) return(res)
     tab <- tabulate(res)
-    DF <- data.frame(Degree = seq_along(tab), Number = tab)
+    DF <- data.frame(Degree = seq_along(tab), N = tab)
     DF[tab > 0, ]
 }
 
@@ -304,6 +317,6 @@ degree.evonet <- function(x, details = FALSE, ...)
     res <- tabulate(x$edge, N) + tabulate(x$reticulation, N)
     if (details) return(res)
     tab <- tabulate(res)
-    DF <- data.frame(Degree = seq_along(tab), Number = tab)
+    DF <- data.frame(Degree = seq_along(tab), N = tab)
     DF[tab > 0, ]
 }
